Script 'mail_helper' called by obssrc
Hello community,

here is the log from the commit of package gasket-driver for openSUSE:Factory 
checked in at 2026-05-07 15:44:40
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Factory/gasket-driver (Old)
 and      /work/SRC/openSUSE:Factory/.gasket-driver.new.1966 (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Package is "gasket-driver"

Thu May  7 15:44:40 2026 rev:6 rq:1351314 version:1.0.18_5815ee3

Changes:
--------
--- /work/SRC/openSUSE:Factory/gasket-driver/gasket-driver.changes      
2026-04-18 21:37:17.819847506 +0200
+++ /work/SRC/openSUSE:Factory/.gasket-driver.new.1966/gasket-driver.changes    
2026-05-07 15:46:26.578729606 +0200
@@ -1,0 +2,5 @@
+Wed May  6 19:55:35 UTC 2026 - Chris Bradbury <[email protected]>
+
+- Add `fix-renamed-zap_vma_ptes.patch`. 
+
+-------------------------------------------------------------------

New:
----
  fix-renamed-zap_vma_ptes.patch

----------(New B)----------
  New:
- Add `fix-renamed-zap_vma_ptes.patch`. 
----------(New E)----------

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ gasket-driver.spec ++++++
--- /var/tmp/diff_new_pack.JaKdDh/_old  2026-05-07 15:46:27.482766860 +0200
+++ /var/tmp/diff_new_pack.JaKdDh/_new  2026-05-07 15:46:27.486767025 +0200
@@ -90,6 +90,14 @@
 # PATCH-FIX-OPENSUSE  fix-for-module-import-ns.patch gh#google/gasket-driver!40
 Patch2:         fix-for-module-import-ns.patch
 
+# In kernel 7.1 the `zap_vma_ptes()` function was renamed to 
`zap_special_vma_range()`.
+#
+# Affects:
+# - Tumbleweed
+#
+# See kernel commit #52a9e9c
+Patch3:         fix-renamed-zap_vma_ptes.patch
+
 # This directive instructs the build service to temporarily save the project's
 # certificate as %%_sourcedir/_projectcert.crt. See:
 # https://github.com/openSUSE/pesign-obs-integration
@@ -128,9 +136,11 @@
 # Apply `fix-for-no_llseek.patch`.
 %patch -P 1 -p1
 
-# Apply `fix-for-module-import-ns.patch`.
 %if 0%{?suse_version} > 1600
+# Apply `fix-for-module-import-ns.patch`.
 %patch -P 2 -p1
+# Apply `fix-renamed-zap_vma_ptes.patch`.
+%patch -P 3 -p1
 %endif
 
 %build

++++++ fix-renamed-zap_vma_ptes.patch ++++++
diff --git a/src/gasket_core.c b/src/gasket_core.c
--- a/src/gasket_core.c (revision 5815ee3908a46a415aac616ac7b9aedcb98a504c)
+++ b/src/gasket_core.c (revision 90d5f57d72d4e770070b2969e79fcfc4c3afcb3c)
@@ -915,14 +915,20 @@
                return 1;
 
        /*
         * The length passed to zap_vma_ptes MUST BE A MULTIPLE OF
MULTIPLE OF
         * PAGE_SIZE! Trust me. I have the scars.
         *
         * Next multiple of y: ceil_div(x, y) * y
         */
+       #if LINUX_VERSION_CODE >= KERNEL_VERSION(7, 1, 0)
+       zap_special_vma_range(vma, vma->vm_start + virt_offset,
+                    DIV_ROUND_UP(mappable_region.length_bytes, PAGE_SIZE) *
+                    PAGE_SIZE);
+       #else
        zap_vma_ptes(vma, vma->vm_start + virt_offset,
                     DIV_ROUND_UP(mappable_region.length_bytes, PAGE_SIZE) *
                     PAGE_SIZE);
+       #endif
        return 0;
 }
 EXPORT_SYMBOL(gasket_mm_unmap_region);
@@ -915,14 +915,20 @@
 
        /*
-        * The length passed to zap_vma_ptes MUST BE A MULTIPLE OF
+        * The length passed to zap_vma_ptes/zap_special_vma_range MUST BE A 
MULTIPLE OF
         * PAGE_SIZE! Trust me. I have the scars.

Reply via email to